==> ckan-2.1.1.tar.gz: ckan-2.1.1/ckan/public/base/i18n/sv.js <==
{
  "": {
    "domain": "ckan",
    "lang": "sv",
    "plural-forms": "nplurals=2; plural=(n != 1);"
  },
  "An Error Occurred": [
    null,
    "Ett fel uppstod"
  ],
  "Are you sure you want to perform this action?": [
    null,
    "Vill du verkligen genomföra denna åtgärd?"
  ],
  "Cancel": [
    null,
    "Avbryt"
  ],
  "Confirm": [
    null,
    "Bekräfta"
  ],
  "Edit": [
    null,
    "Redigera"
  ],
  "Failed to load data API information": [
    null,
    "Misslyckades med att ladda API-information"
  ],
  "Follow": [
    null,
    "Följ"
  ],
  "Hide": [
    null,
    "Dölj"
  ],
  "Input is too short, must be at least one character": [
    null,
    "För kort inmatning. Det måste vara åtminstone ett tecken"
  ],
  "Loading...": [
    null,
    "Laddar..."
  ],
  "No matches found": [
    null,
    "Hittades inte"
  ],
  "Please Confirm Action": [
    null,
    "Vänligen Bekräfta Åtgärd"
  ],
  "Resource uploaded": [
    null,
    "Resursen laddades upp"
  ],
  "Show more": [
    null,
    "Visa mer"
  ],
  "Start typing…": [
    null,
    "Börja skriv..."
  ],
  "There are unsaved modifications to this form": [
    null,
    "Det finns ändringar i detta formulär som inte sparats"
  ],
  "There is no API data to load for this resource": [
    null,
    "Det finns inga API-data att ladda för denna resurs"
  ],
  "URL": [
    null,
    "URL"
  ],
  "Unable to authenticate upload": [
    null,
    "Kunde inte verifiera behörighet för uppladdningen"
  ],
  "Unable to get data for uploaded file": [
    null,
    "Kunde inte läsa data i den uppladdade filen"
  ],
  "Unable to upload file": [
    null,
    "Kunde inte ladda upp filen"
  ],
  "Unfollow": [
    null,
    "Sluta följa"
  ],
  "Upload a file": [
    null,
    "Ladda upp en fil"
  ],
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null,
    "Du laddar upp en fil. Är du säker på att du vill lämna sidan och avbryta uppladdningen?"
  ],
  "show less": [
    null,
    "visa mindre"
  ],
  "show more": [
    null,
    "visa mer"
  ]
}

==> ckan-2.2.1.tar.gz: ckan-2.2.1/ckan/public/base/i18n/sv.js <==
{
  "": {
    "domain": "ckan",
    "lang": "sv",
    "plural-forms": "nplurals=2; plural=(n != 1);"
  },
  "An Error Occurred": [
    null,
    "Ett fel uppstod"
  ],
  "Are you sure you want to perform this action?": [
    null,
    "Vill du verkligen genomföra denna åtgärd?"
  ],
  "Cancel": [
    null,
    "Avbryt"
  ],
  "Confirm": [
    null,
    "Bekräfta"
  ],
  "Edit": [
    null,
    "Redigera"
  ],
  "Failed to load data API information": [
    null,
    "Misslyckades med att ladda API-information"
  ],
  "Follow": [
    null,
    "Följ"
  ],
  "Hide": [
    null,
    "Dölj"
  ],
  "Image": [
    null,
    "Bild"
  ],
  "Input is too short, must be at least one character": [
    null,
    "För kort inmatning. Det måste vara åtminstone ett tecken"
  ],
  "Link": [
    null,
    "Länk"
  ],
  "Link to a URL on the internet (you can also link to an API)": [
    null,
    "Länk till en URL på internet (du kan också länka till ett API)"
  ],
  "Loading...": [
    null,
    "Laddar..."
  ],
  "No matches found": [
    null,
    "Hittades inte"
  ],
  "Please Confirm Action": [
    null,
    "Vänligen Bekräfta Åtgärd"
  ],
  "Remove": [
    null,
    "Ta bort"
  ],
  "Reorder resources": [
    null,
    "Ändra ordning på resurser"
  ],
  "Reset this": [
    null,
    "Återställ detta"
  ],
  "Resource uploaded": [
    null,
    "Resursen laddades upp"
  ],
  "Save order": [
    null,
    "Spara ordning"
  ],
  "Saving...": [
    null,
    "Sparar..."
  ],
  "Show more": [
    null,
    "Visa mer"
  ],
  "Start typing…": [
    null,
    "Börja skriv..."
  ],
  "There are unsaved modifications to this form": [
    null,
    "Det finns ändringar i detta formulär som inte sparats"
  ],
  "There is no API data to load for this resource": [
    null,
    "Det finns inga API-data att ladda för denna resurs"
  ],
  "URL": [
    null,
    "URL"
  ],
  "Unable to authenticate upload": [
    null,
    "Kunde inte verifiera behörighet för uppladdningen"
  ],
  "Unable to get data for uploaded file": [
    null,
    "Kunde inte läsa data i den uppladdade filen"
  ],
  "Unable to upload file": [
    null,
    "Kunde inte ladda upp filen"
  ],
  "Unfollow": [
    null,
    "Sluta följa"
  ],
  "Upload": [
    null,
    "Ladda upp"
  ],
  "Upload a file": [
    null,
    "Ladda upp en fil"
  ],
  "Upload a file on your computer": [
    null,
    "Ladda upp en fil från din dator"
  ],
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null,
    "Du laddar upp en fil. Är du säker på att du vill lämna sidan och avbryta uppladdningen?"
  ],
  "show less": [
    null,
    "visa mindre"
  ],
  "show more": [
    null,
    "visa mer"
  ]
}
